@@ -44,7 +44,19 @@ def getAccountInfo(account):
   return solcatcherPostRequest('accountinfo',**{"account":account})
 def getTokenAccountBalance(account):
   return solcatcherPostRequest('tokenaccountbalance',**{"account":account})
-def getTokenAccountByOwner(account):
-  return solcatcherPostRequest('tokenaccountsbyowner',**{"account":account})
+def getTokenAccountByOwner(account,mint):
+  return solcatcherPostRequest('tokenaccountsbyowner',**{"account":account,"mint":mint})
 def getPoolInfo(address=None,signature=None,txData=None):
   return solcatcherPostRequest('getpoolinfo',**{"address":address,"signature":signature,"txData":txData})
+def get_genesis_signature(account):
+  limit=1000
+  before=None
+  SignaturesFromAddress = solcatcherPostRequest('signaturesforaddress',address=account, limit=limit, before=before)
+  before = SignaturesFromAddress[-1].get('signature')
+  
+  while True:
+    SignaturesFromAddress = solcatcherPostRequest('signaturesforaddress',address=account, limit=limit, before=before)
+    if SignaturesFromAddress:
+      before = SignaturesFromAddress[-1].get('signature')
+    if len(SignaturesFromAddress)<limit:
+      return before
